@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "capnp-mode" "1.3.0"
+(define-package "capnp-mode" "20260106.2017"
   "Major mode for editing Capn' Proto Files."
   ()
   :url "https://github.com/capnproto/capnproto"
-  :commit "7dbb95989721016f8b590245ec7528c6ff03d1fe"
-  :revdesc "7dbb95989721"
+  :commit "92327754f61963a2b4f0edbd299246ed1d42e665"
+  :revdesc "92327754f619"
   :authors '(("Brian Taylor" . "el.wubo@gmail.com"))
   :maintainers '(("Brian Taylor" . "el.wubo@gmail.com")))
